@@ -330,18 +330,12 @@ class CHPControlMultiEnergy(G2PControlMultiEnergy):
             gas_flow
             * self.conversion_factor_kgps_to_mw()
             * 1000000
-            * (0.000028 * self.__ambient_temperature_in_k + 273.3567)
-            + 2.1609 * self.__ambient_temperature_in_k
-            + 339.714
+            * (1 - self.efficiency)
         )
 
     @property
     def heat_efficiency(self):
-        return (
-            (0.000028 * self.__ambient_temperature_in_k + 273.3567)
-            + 2.1609 * self.__ambient_temperature_in_k
-            + 339.714
-        ) * (1 - self.efficiency)
+        return 1 - self.efficiency
 
     def control_step(self, mn):
         self.time_step(mn, 0)
