@@ -23,7 +23,7 @@ class MESModel(abc.ABC):
         pass
 
     def properties_as_dict(self):
-        return self._network[self.component_type()].iloc[self._id]
+        return self._network[self.component_type()].loc[self._id]
 
 
 class RegulatableMESModel(MESModel):
