@@ -54,9 +54,27 @@ class RegulatableController(RegulatableMESModel):
         return self._network.controller[CONTROLLER_OBJ_KEY][self._id]
 
 
-class G2PNode(RegulatableController):
+class CouplingPoint(RegulatableController):
+    def loss_perc(self):
+        return 1 - self.controller.efficiency
+
+    @property
+    def networks(self):
+        return self.controller.get_all_net_names()
+
+
+class G2PNode(CouplingPoint):
     """Node representing g2p system. Contains wrapper functions for accessing the relevant information and control variables."""
 
+    def edge_description(self) -> dict:
+        return [
+            (
+                self.controller.name_net_gas,
+                self.controller.name_net_power,
+                self.controller.efficiency,
+            )
+        ]
+
     def power_output(self) -> float:
         """
         :return: Actual mass flow
@@ -90,9 +108,18 @@ class G2PNode(RegulatableController):
         }
 
 
-class P2GNode(RegulatableController):
+class P2GNode(CouplingPoint):
     """Node representing p2g system. Contains wrapper functions for accessing the relevant information and control variables."""
 
+    def edge_description(self) -> dict:
+        return [
+            (
+                self.controller.name_net_power,
+                self.controller.name_net_gas,
+                self.controller.efficiency,
+            )
+        ]
+
     def mdot_kg_per_s(self) -> float:
         """
         :return: Actual mass flow
@@ -129,9 +156,23 @@ class P2GNode(RegulatableController):
         }
 
 
-class CHPNode(RegulatableController):
+class CHPNode(CouplingPoint):
     """Node representing chp with gas turbine system. Contains wrapper functions for accessing the relevant information and control variables."""
 
+    def edge_description(self) -> dict:
+        return [
+            (
+                self.controller.name_net_gas,
+                self.controller.name_net_power,
+                self.controller.efficiency,
+            ),
+            (
+                self.controller.name_net_gas,
+                self.controller.name_net_heat,
+                self.controller.heat_efficiency,
+            ),
+        ]
+
     def heat_output(self) -> float:
         return self.network.controller[CONTROLLER_OBJ_KEY][self.id].heat_energy
 
@@ -174,9 +215,18 @@ class CHPNode(RegulatableController):
         return self.network.controller[CONTROLLER_OBJ_KEY][self.id].state_as_dict()
 
 
-class P2HNode(RegulatableController):
+class P2HNode(CouplingPoint):
     """Node representing P2H."""
 
+    def edge_description(self) -> dict:
+        return [
+            (
+                self.controller.name_net_power,
+                self.controller.name_net_heat,
+                self.controller.efficiency,
+            )
+        ]
+
     def heat_output(self) -> float:
         return self.network.controller[CONTROLLER_OBJ_KEY][self.id].heat_energy
 
@@ -254,7 +304,7 @@ class PowerLoadNode(RegulatableMESModel):
         return "load"
 
     def values_as_dict(self):
-        return self._network.res_load.iloc[self._id]
+        return self._network.res_load.loc[self._id]
 
 
 class SwitchNode(RegulatableMESModel):
@@ -279,7 +329,7 @@ class SwitchNode(RegulatableMESModel):
         return "switch"
 
     def values_as_dict(self):
-        return self._network.res_switch.iloc[self._id]
+        return {}
 
 
 class SGeneratorNode(RegulatableMESModel):
@@ -334,7 +384,7 @@ class SGeneratorNode(RegulatableMESModel):
         return "sgen"
 
     def values_as_dict(self):
-        return self._network.res_sgen.iloc[self._id]
+        return self._network.res_sgen.loc[self._id]
 
 
 class GeneratorNode(RegulatableMESModel):
@@ -403,7 +453,7 @@ class GeneratorNode(RegulatableMESModel):
         return "gen"
 
     def values_as_dict(self):
-        return self._network.res_gen.iloc[self._id]
+        return self._network.res_gen.loc[self._id]
 
 
 class SinkNode(RegulatableMESModel):
@@ -451,7 +501,7 @@ class SinkNode(RegulatableMESModel):
         return "sink"
 
     def values_as_dict(self):
-        return self._network.res_sink.iloc[self._id]
+        return self._network.res_sink.loc[self._id]
 
 
 class SourceNode(RegulatableMESModel):
@@ -499,7 +549,7 @@ class SourceNode(RegulatableMESModel):
         return "source"
 
     def values_as_dict(self):
-        return self._network.res_source.iloc[self._id]
+        return self._network.res_source.loc[self._id]
 
 
 class HeatExchangerNode(RegulatableMESModel):
@@ -556,7 +606,7 @@ class HeatExchangerNode(RegulatableMESModel):
 
     def values_as_dict(self):
         return {
-            **self._network.res_heat_exchanger.iloc[self._id],
+            **self._network.res_heat_exchanger.loc[self._id],
             "qext_w": self._network.heat_exchanger[QEXT_W][self._id],
         }
 
@@ -591,7 +641,7 @@ class ExtGasGrid(RegulatableMESModel):
         return "ext_grid"
 
     def values_as_dict(self):
-        return self._network.res_ext_grid.iloc[self._id]
+        return self._network.res_ext_grid.loc[self._id]
 
 
 class ExtPowerGrid(RegulatableMESModel):
@@ -624,7 +674,7 @@ class ExtPowerGrid(RegulatableMESModel):
         return "ext_grid"
 
     def values_as_dict(self):
-        return self._network.res_ext_grid.iloc[self._id]
+        return self._network.res_ext_grid.loc[self._id]
 
 
 class EmptyBusNode(RegulatableMESModel):
@@ -649,7 +699,7 @@ class EmptyBusNode(RegulatableMESModel):
         return "bus"
 
     def values_as_dict(self):
-        return self._network.res_bus.iloc[self._id]
+        return self._network.res_bus.loc[self._id]
 
 
 class EmptyJunctionNode(RegulatableMESModel):
@@ -663,7 +713,7 @@ class EmptyJunctionNode(RegulatableMESModel):
         return 0
 
     def name(self):
-        """Return name of the ext grid
+        """Return name of the junction
 
         :return: the name
         :rtype: str
@@ -674,4 +724,4 @@ class EmptyJunctionNode(RegulatableMESModel):
         return "junction"
 
     def values_as_dict(self):
-        return self._network.res_junction.iloc[self._id]
+        return self._network.res_junction.loc[self._id]
